@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 import os
 from contextlib import contextmanager
-from typing import Dict, List
+from typing import Dict, Generator, List
 
 import httpx
 import yaml
@@ -10,24 +9,24 @@ from chaoslib.exceptions import ActivityFailed
 from chaoslib.types import Configuration, DiscoveredActivities, Discovery, Secrets
 from logzero import logger
 
-__version__ = "0.2.1"
+__version__ = "0.3.0"
 __all__ = ["get_session", "discover"]
 RELIABLY_CONFIG_PATH = "~/.config/reliably/config.yaml"
-RELIABLY_HOST = "api.reliably.com"
+RELIABLY_HOST = "reliably.com"
 
 
 @contextmanager
 def get_session(
     configuration: Configuration = None, secrets: Secrets = None
-) -> httpx.Client:
+) -> Generator[httpx.Client, None, None]:
     auth_info = get_auth_info(configuration, secrets)
     headers = {
         "Content-Type": "application/json",
         "Authorization": "Bearer {}".format(auth_info["token"]),
     }
     with httpx.Client() as client:
-        client.headers = headers
-        client.reliably_url = (
+        client.headers = httpx.Headers(headers)
+        client.base_url = httpx.URL(
             f"https://{auth_info['host']}/entities/{auth_info['org']}/reliably.com/v1"
         )
         yield client
@@ -71,7 +70,7 @@ def get_auth_info(
     reliably_org = secrets.get("org")
 
     if not reliably_token and reliably_config_path:
-        logger.debug("Loading Reliably config from: {}".format(reliably_config_path))
+        logger.debug(f"Loading Reliably config from: {reliably_config_path}")
         with open(reliably_config_path) as f:
             try:
                 config = yaml.safe_load(f)
@@ -81,7 +80,7 @@ def get_auth_info(
                     "'{}': {}".format(reliably_config_path, str(ye))
                 )
         reliably_host = reliably_host or RELIABLY_HOST
-        logger.debug("Connecting to Reliably: {}".format(reliably_host))
+        logger.debug(f"Connecting to Reliably: {reliably_host}")
         auth_hosts = config.get("auths", {})
         for auth_host, values in auth_hosts.items():
             if auth_host == reliably_host:
@@ -99,7 +98,7 @@ def get_auth_info(
     ):
         raise ActivityFailed(
             "Make sure to login against Reliably's services and/or provide "
-            "them correct authentication information to the experiment."
+            "the correct authentication information to the experiment."
         )
 
     if not reliably_token:
