@@ -1,7 +1,9 @@
 from tempfile import NamedTemporaryFile
+from typing import Any
 from urllib.parse import quote
 
 import pytest
+import pytest_httpx
 import yaml
 from chaoslib.exceptions import ActivityFailed
 
@@ -9,8 +11,8 @@ from chaosreliably.slo.probes import get_objective_results_by_labels
 
 
 def test_that_get_objective_results_by_label_returns_correct_results(
-    httpx_mock, objective_results
-):
+    httpx_mock: pytest_httpx._httpx_mock.HTTPXMock, results: Any
+) -> None:
     labels = {
         "name": "exploring-reliability-guide",
         "service": "exploring-reliability-guide-service",
@@ -19,15 +21,15 @@ def test_that_get_objective_results_by_label_returns_correct_results(
         ",".join([f"{key}={value}" for key, value in labels.items()])
     )
     request_url = (
-        "https://api.reliably.com/entities/test-org/reliably.com/v1/objectiveresult"
+        "https://reliably.com/entities/test-org/reliably.com/v1/objectiveresult"
         f"?objective-match={encoded_labels}&limit=1"
     )
-    httpx_mock.add_response(method="GET", url=request_url, json=objective_results[:1])
+    httpx_mock.add_response(method="GET", url=request_url, json=results[:1])
 
     with NamedTemporaryFile(mode="w") as f:
         yaml.safe_dump(
             {
-                "auths": {"api.reliably.com": {"token": "12345", "username": "jane"}},
+                "auths": {"reliably.com": {"token": "12345", "username": "jane"}},
                 "currentOrg": {"name": "test-org"},
             },
             f,
@@ -35,13 +37,15 @@ def test_that_get_objective_results_by_label_returns_correct_results(
             default_flow_style=False,
         )
         f.seek(0)
-        results = get_objective_results_by_labels(
+        res = get_objective_results_by_labels(
             labels=labels, configuration={"reliably_config_path": f.name}, secrets=None
         )
-        assert len(results) == 1
+        assert len(res) == 1
 
 
-def test_that_get_objective_results_by_label_raises_exception_if_non_200(httpx_mock):
+def test_that_get_objective_results_by_label_raises_exception_if_non_200(
+    httpx_mock: pytest_httpx._httpx_mock.HTTPXMock,
+) -> None:
     labels = {
         "name": "exploring-reliability-guide",
         "service": "exploring-reliability-guide-service",
@@ -50,7 +54,7 @@ def test_that_get_objective_results_by_label_raises_exception_if_non_200(httpx_m
         ",".join([f"{key}={value}" for key, value in labels.items()])
     )
     request_url = (
-        "https://api.reliably.com/entities/test-org/reliably.com/v1/objectiveresult"
+        "https://reliably.com/entities/test-org/reliably.com/v1/objectiveresult"
         f"?objective-match={encoded_labels}&limit=1"
     )
     httpx_mock.add_response(method="GET", url=request_url, status_code=400)
@@ -59,9 +63,7 @@ def test_that_get_objective_results_by_label_raises_exception_if_non_200(httpx_m
         with NamedTemporaryFile(mode="w") as f:
             yaml.safe_dump(
                 {
-                    "auths": {
-                        "api.reliably.com": {"token": "12345", "username": "jane"}
-                    },
+                    "auths": {"reliably.com": {"token": "12345", "username": "jane"}},
                     "currentOrg": {"name": "test-org"},
                 },
                 f,
@@ -77,8 +79,8 @@ def test_that_get_objective_results_by_label_raises_exception_if_non_200(httpx_m
 
 
 def test_that_get_objective_results_by_label_passes_limit_parameter_correctly(
-    httpx_mock, objective_results
-):
+    httpx_mock: pytest_httpx._httpx_mock.HTTPXMock, results: Any
+) -> None:
     labels = {
         "name": "exploring-reliability-guide",
         "service": "exploring-reliability-guide-service",
@@ -87,15 +89,15 @@ def test_that_get_objective_results_by_label_passes_limit_parameter_correctly(
         ",".join([f"{key}={value}" for key, value in labels.items()])
     )
     request_url = (
-        "https://api.reliably.com/entities/test-org/reliably.com/v1/objectiveresult"
+        "https://reliably.com/entities/test-org/reliably.com/v1/objectiveresult"
         f"?objective-match={encoded_labels}&limit=20"
     )
-    httpx_mock.add_response(method="GET", url=request_url, json=objective_results)
+    httpx_mock.add_response(method="GET", url=request_url, json=results)
 
     with NamedTemporaryFile(mode="w") as f:
         yaml.safe_dump(
             {
-                "auths": {"api.reliably.com": {"token": "12345", "username": "jane"}},
+                "auths": {"reliably.com": {"token": "12345", "username": "jane"}},
                 "currentOrg": {"name": "test-org"},
             },
             f,
@@ -103,10 +105,10 @@ def test_that_get_objective_results_by_label_passes_limit_parameter_correctly(
             default_flow_style=False,
         )
         f.seek(0)
-        results = get_objective_results_by_labels(
+        res = get_objective_results_by_labels(
             labels=labels,
             limit=20,
             configuration={"reliably_config_path": f.name},
             secrets=None,
         )
-        assert len(results) == 10
+        assert len(res) == 10
